# CST-Python-API/Wrapper

Some features of CST can be controlled via COM objects, this in combination with a feature rich IDE (such as Spyder or PyCharm) allows for more sophisticated levels of optimisation/automation than what is available through the standard package.

Integration with the Python environment will allow for an immersive post-processing experience that combines powerful scientific packages with a sophisticated 3D EM solver.

Note, this is inspired by the unofficial MATLAB API. Much work and restructuring is needed, this is more of a proof of concept really. 





![ezgif-2-d897ceadac](https://user-images.githubusercontent.com/10766516/151979056-15130b97-9954-4d0d-b033-af22d79cd888.gif)
## [Watch the video](https://www.youtube.com/watch?v=D5FbC2xe0oU)

<!-- # Example using Python to form a N x N patch with 1mm x 1mm PEC squares.
![alt text](https://github.com/Yates1011/CST-Python-API/blob/f28bebd648a78ea4dd45e7a4a34c9c543cb5a4a4/patch_grid%5B1%5D.png)-->

Documentation available [here](https://pycst.readthedocs.io/en/latest/index.html).
